@@ -30,14 +30,14 @@ ProcrustesSimple <- function (X, Y, centre = FALSE)
   Procrustes$xmean = apply(X, 2, mean)
   Procrustes$X = X
   Procrustes$Y = Y
-  C = t(X) %*% J %*% Y
+  C = t(X) %*% Y
   SVD = svd(C)
-  T = SVD$u %*% t(SVD$v)
-  s = tr(C %*% T)/tr(t(Y) %*% J %*% Y)
-  t = apply((X - s * Y %*% T), 2, sum)/ny
-  Z = s * Y %*% T + matrix(1, nx, 1) %*% t
+  TT = SVD$u %*% t(SVD$v)
+  s=tr(TT %*% t(Y) %*% X)/tr(t(Y) %*% Y)
+  t = apply((X - s * Y %*% TT), 2, sum)/ny
+  Z = s * Y %*% TT + matrix(1, nx, 1) %*% t
   Procrustes$Yrot = Z
-  Procrustes$rotation = T
+  Procrustes$rotation = TT
   Procrustes$translation = t
   Procrustes$scale = s
   Procrustes$rss = sum((X - Z)^2)
